import os
from os.path import basename, dirname, join, isfile
import subprocess
from typing import List
from glob import glob
import shutil
import logging

from ..util import replace_ext


logger = logging.getLogger(__name__)


def calc_step(source_dir: os.PathLike, target_dir: os.PathLike, preprocessor_config: dict, formulas: List[dict]):
    for i, item in enumerate(formulas):
        # get first filename as a base
        filename = glob(join(source_dir, list(item['inputs'].values())[0]['glob']))[0]
        target_filename = join(
            target_dir,
            replace_ext(basename(filename), item.get('output_postfix', '_proc%d' % i) + '.tif', False)
        )

        if isfile(target_filename):
            logger.warn('Calc output filename %s already exists' % target_filename)

        calc_formula(source_dir, item['inputs'], target_filename, item['formula'], item.get('data_type', 'Float32'), item.get('nodata_value', None))

    # take all original files with from the last step
    for filename in glob('%s/*' % source_dir):
        target_filename = join(target_dir, basename(filename))
        if isfile(target_filename):
            logger.warn('Calc output filename %s already exists' % target_filename)
        shutil.copy(filename, target_filename)


def calc_formula(source_dir: os.PathLike, inputs: List[dict], target_filename: os.PathLike, formula: str, data_type: str="Float32", nodata_value: float=None):
    cmd = [
        "gdal_calc.py",
        "--calc=%s" % formula,
        "--outfile=%s" % target_filename,
        "--type", data_type,
    ]

    for name in inputs:
        # select first
        filename = glob(join(source_dir, inputs[name]['glob']))[0]
        cmd.extend([
            "-%s" % name, filename,
            "--%s_band=%d" % (name, inputs[name].get('band', 1)),
        ])

    if nodata_value is not None:
        cmd.append("--NoDataValue=%f" % nodata_value)

    subprocess.run(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
