import os
from os.path import join, basename
from uuid import uuid4
from glob import glob

from ..util import replace_ext, gdal
import logging

logger = logging.getLogger(__name__)


def output_step(source_dir: os.PathLike, target_dir: os.PathLike, preprocessor_config: dict, options: dict=None):
    # find out the driver to get the extension
    options = options if options is not None else {}
    frmt = options.get('format', 'GTiff')
    driver = gdal.GetDriverByName(frmt)
    if not driver:
        raise ValueError('Unsupported driver %s' % frmt)
    extension = driver.GetMetadata().get('DMD_EXTENSIONS', 'tif').split(' ')[0]
    # warp each individual file
    warped_files = []
    filenames = []
    for dataglob in preprocessor_config.get('data_file_globs', '*'):
        for p in [path for path in glob(join(source_dir, '**', dataglob), recursive=True) if not os.path.isdir(path)]:
            filenames.append(p)
    for filename in filenames:
        target_filename = join(target_dir, replace_ext(basename(filename), extension))
        logger.debug('Warping file %s' % filename)
        gdal.Warp(target_filename, filename, **options)
        warped_files.append(target_filename)

    if len(warped_files) > 1:
        tmp_filename = join(target_dir, '%s.%s' % (uuid4().hex, extension))
        logger.debug('Warping files %s' % warped_files)
        gdal.Warp(tmp_filename, warped_files, **options)

        # delete old files and rename the combined file to the first filename
        for filename in warped_files:
            os.unlink(filename)
        os.rename(tmp_filename, warped_files[0])
